@@ -3,8 +3,9 @@
 
 """postcard"""
 
+from postcard.imap import *
 from postcard.pop3 import *
 from postcard.smtp import *
 
 
-__version__ = "0.2"
+__version__ = "0.3.1"
