@@ -33,7 +33,7 @@ class Pop3(object):
             self.pop_addr = self._set_pop_addr_auto(user)
 
         if not self.pop_port:
-            self.pop_port = 995 if ssl else 110
+            self.pop_port = poplib.POP3_SSL_PORT if ssl else poplib.POP3_PORT
 
         if ssl:
             self._client = poplib.POP3_SSL(self.pop_addr, self.pop_port)
