@@ -30,3 +30,8 @@ SMTP_ADDR = {
     "sina": "smtp.sina.com.cn",
     "88": "smtp.88.com",
 }
+
+IMAP_ADDR = {
+    "tom": "imap.tom.com",
+    "88": "imap.88.com",
+}
