@@ -35,7 +35,7 @@ class Smtp(object):
             self.smtp_addr = self._set_smtp_addr_auto(user)
 
         if not self.smtp_port:
-            self.smtp_port = 465 if ssl else 25
+            self.smtp_port = smtplib.SMTP_SSL_PORT if ssl else smtplib.SMTP_PORT
 
         if ssl:
             self._client = smtplib.SMTP_SSL(self.smtp_addr, self.smtp_port)
